@@ -1,5 +1,4 @@
 import pickle
-from datetime import timedelta
 from typing import Any
 
 from redis import Redis
@@ -16,7 +15,10 @@ class SessionStorage:
         return raw and pickle.loads(raw)
 
     def __setitem__(self, key: str, value: Any):
-        self.client.set(key, pickle.dumps(value, protocol=pickle.HIGHEST_PROTOCOL), ex=timedelta(hours=6))
+        self.client.set(key, pickle.dumps(value, protocol=pickle.HIGHEST_PROTOCOL), ex=config.expireTime)
+
+    def __delitem__(self, key: str):
+        self.client.delete(key)
 
     def genSessionId(self) -> str:
         sessionId = config.genSessionId()
